@@ -27,9 +27,9 @@
 #include <kcalcore/freebusy.h>
 #include <kcalcore/icalformat.h>
 
-#include <QtCore/QPointer>
-#include <QtDBus/QDBusContext>
-#include <QtDBus/QDBusInterface>
+#include <QPointer>
+#include <QDBusContext>
+#include <QDBusInterface>
 
 #include <KJob>
 #include <QUrl>
@@ -66,13 +66,11 @@ public: /// Structs
     };
 
     struct FreeBusyProvidersRequestsQueue {
-        explicit FreeBusyProvidersRequestsQueue(const QString &start = QString(),
-                                                const QString &end = QString());
+        FreeBusyProvidersRequestsQueue();
+        FreeBusyProvidersRequestsQueue(const QDateTime &start, const QDateTime &end);
 
-        FreeBusyProvidersRequestsQueue(const KDateTime &start, const KDateTime &end);
-
-        QString mStartTime;
-        QString mEndTime;
+        QDateTime mStartTime;
+        QDateTime mEndTime;
         QList<FreeBusyProviderRequest> mRequests;
         int mHandlersCount;
         KCalCore::FreeBusy::Ptr mResultingFreeBusy;
@@ -112,7 +110,7 @@ public: /// Functions
     QStringList getFreeBusyProviders() const;
     void queryFreeBusyProviders(const QStringList &providers, const QString &email);
     void queryFreeBusyProviders(const QStringList &providers, const QString &email,
-                                const KDateTime &start, const KDateTime &end);
+                                const QDateTime &start, const QDateTime &end);
 
 public Q_SLOTS:
     void processRetrieveQueue();
@@ -133,7 +131,7 @@ class FbCheckerJob : public KJob
     Q_OBJECT
 public:
     explicit FbCheckerJob(const QList<QUrl> &urlsToCheck, QObject *parent = nullptr);
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
     QUrl validUrl() const;
 
