@@ -158,7 +158,7 @@ void MailClient::mailTo(const KCalCore::IncidenceBase::Ptr &incidence,
     QString subject;
 
     if (incidence->type() != KCalCore::Incidence::TypeFreeBusy) {
-        KCalCore::Incidence::Ptr inc = incidence.staticCast<KCalCore::Incidence>() ;
+        KCalCore::Incidence::Ptr inc = incidence.staticCast<KCalCore::Incidence>();
         subject = inc->summary();
     } else {
         subject = i18n("Free Busy Message");
@@ -191,7 +191,6 @@ void MailClient::send(const KCalCore::IncidenceBase::Ptr &incidence,
                       const QString &attachment, const QString &mailTransport)
 {
     Q_UNUSED(hidden);
-
     if (!MailTransport::TransportManager::self()->showTransportCreationDialog(
                 nullptr, MailTransport::TransportManager::IfNoTransportExists)) {
         qCritical() << "Error while creating transport";
@@ -205,6 +204,8 @@ void MailClient::send(const KCalCore::IncidenceBase::Ptr &incidence,
     if (to.isEmpty()) {
         to = from;
     }
+    to = KEmailAddress::extractEmailAddress(
+                                       KEmailAddress::normalizeAddressesAndEncodeIdn(to));
     qCDebug(AKONADICALENDAR_LOG) << "\nFrom:" << from
                                  << "\nTo:" << to
                                  << "\nCC:" << cc
@@ -232,7 +233,7 @@ void MailClient::send(const KCalCore::IncidenceBase::Ptr &incidence,
     const int transportId = transport->id();
 
     // gather config values
-    KConfig config(QStringLiteral("mailviewerrc"));
+    KConfig config(QStringLiteral("kmail2rc"));
 
     KConfigGroup configGroup(&config, QStringLiteral("Invitations"));
     const bool outlookConformInvitation = configGroup.readEntry("LegacyBodyInvites",
